@@ -19,18 +19,21 @@ X, y = make_classification(100000)
 # cats = X.dtypes[X.dtypes == object].index
 # for i in cats:
 #     X[i] = X[i].astype(str)
-model = CatBoostClassifier(loss_function="Logloss",
-                           eval_metric="AUC",
-                           task_type="GPU",
-                           learning_rate=0.05,
-                           n_estimators=10000,
-                           l2_leaf_reg=50,
-                           random_seed=666,
-                           od_type="Iter",
-                           depth=5,
-                           early_stopping_rounds=100,
-                           border_count=64,
-                           has_time=True
-                           )
+model = CatBoostClassifier(
+    loss_function="Logloss",
+    eval_metric="AUC",
+    learning_rate=0.05,
+    n_estimators=10000,
+    l2_leaf_reg=50,
+    random_seed=666,
+    od_type="Iter",
+    depth=5,
+    early_stopping_rounds=100,
+    border_count=64,
+    has_time=True,
+    verbose=0,
+    thread_count=30,
+    task_type="GPU",
+)
 
 model.fit(X, y, eval_set=(X, y), verbose=1000, use_best_model=True, plot=True)
