@@ -41,7 +41,7 @@ class FilterFeatures(object):
 
         self.df = df
 
-        exclude.append(df.select_dtypes(['datetime64[ns]', object]).columns.tolist())
+        exclude += df.select_dtypes(['datetime64[ns]', object]).columns.tolist()
         print(f"Exclude Fetures: {exclude}")
 
         if exclude:
