@@ -17,7 +17,7 @@ from catboost import CatBoostClassifier
 class CatBoostClassifierOOF(BaseOOF):
 
     def fit_predict(self, X_train, y_train, X_valid, y_valid, X_test, **kwargs):
-        clf = CatBoostClassifier()  # TODO: embedding_features
+        clf = CatBoostClassifier(thread_count=30)  # TODO: embedding_features
         if self.params is not None:
             clf.set_params(**self.params)
             # print(clf.get_params())
