@@ -31,6 +31,7 @@ from functools import reduce
 from functools import lru_cache
 from collections import Counter, OrderedDict
 from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
+from sklearn.metrics.pairwise import cosine_similarity
 
 warnings.filterwarnings("ignore")
 tqdm.pandas()
@@ -122,6 +123,7 @@ xsum, xmin, xmax, xabs, xlen, xmean, xmedian = [xx(i) for i in __funcs]
 xnorm = xx(lambda iterable, ord=2: np.linalg.norm(iterable, ord))
 xl1 = xx(lambda iterable: np.linalg.norm(iterable, 1))
 xl2 = xx(lambda iterable: np.linalg.norm(iterable, 2))
+xcosine = xx(lambda pair_vector: cosine_similarity(pair_vector)[0][1])
 
 xcount = xx(lambda iterable: Counter(list(iterable)))
 
